
#include <amanda.h>
#include <dgram.h>

struct dgram_data {
    char hostname[256];
    int chk;
    int seq;
};

char *pname = "updtest";

void main(int argc, char **argv)
{
    char *peerhost;
    int port, outport, seq, prev_inseq, cur_inseq, insize, outseq;
    dgram_t outmsg, inmsg;
    struct dgram_data outdata, *indata;
    struct sockaddr_in fromaddr;

    if(argc < 3) {
	fprintf(stderr, "Usage: updtest <hostname> <port>\n");
	exit(1);
    }

    peerhost = argv[1];
    port = atoi(argv[2]);
    fprintf(stderr, "updtest: talking to %s using port %d\n", peerhost, port);

    if(dgram_bind_to(&inmsg, port) == -1) {
	fprintf(stderr, "udptest: binding to port %d: %s\n",
		port, strerror(errno));
	exit(1);
    }

    if(dgram_bind(&outmsg, &outport) == -1) {
	fprintf(stderr, "udptest: binding outport: %s\n", strerror(errno));
	exit(1);
    }

    gethostname(outdata.hostname, 255);
    outdata.chk = 0x69696969;
    outseq = 0;

    prev_inseq = -1;

    while(1) {
	sleep(1);
	/* send one */
	dgram_zero(&outmsg);
	outseq++;
	outdata.seq = htonl(outseq);
	memcpy(outmsg.data, &outdata, sizeof(outdata));
	outmsg.len = sizeof(outdata);
	fprintf(stderr, "SENDING seq %d\n", outseq);
	if(dgram_send(peerhost, port, &outmsg) == -1) {
	    fprintf(stderr, "updtest: send: %s\n", strerror(errno));
	}

	/* recv one */
	insize = dgram_recv(&inmsg, 2, &fromaddr);
	switch(insize) {
	case 0:
	    fprintf(stderr, "updtest: recv timeout: last inseq %d\n",
		    prev_inseq);
	    break;
	case -1:
	    fprintf(stderr, "updtest: recv error: %s\n", strerror(errno));
	    break;
	case sizeof(struct dgram_data):
	    indata = (struct dgram_data *) inmsg.data;
	    if(indata->chk != 0x69696969)
		fprintf(stderr, "updtest: recv error: garbled message\n");
	    else {
		cur_inseq = ntohl(indata->seq);
		fprintf(stderr, "RECEIVED seq %d", cur_inseq);
		if(cur_inseq != prev_inseq + 1)
		    fprintf(stderr, " (out of order: prev %d)\n", prev_inseq);
		else fprintf(stderr, "\n");
		prev_inseq = cur_inseq;
	    }
	    break;
	default:
	    fprintf(stderr, "updtest: recv bad size %d: expected %d\n",
		    insize, sizeof(struct dgram_data));
	    break;
	}
    }

    exit(0);
}

int dgram_bind_to(dgram, portint)
dgram_t *dgram;
int portint;
{
    int s, len;
    struct sockaddr_in name;
    short port;

    if((s = socket(AF_INET, SOCK_DGRAM, 0)) == -1) 
        return -1;

    memset(&name, 0, sizeof(name));
    name.sin_family = AF_INET;
    name.sin_addr.s_addr = INADDR_ANY;

    port = portint;
    name.sin_port = htons(port);
    if(bind(s, (struct sockaddr *)&name, sizeof name) == -1) {
	close(s);
	return -1;
    }
 
    len = sizeof name;
    if(getsockname(s, (struct sockaddr *)&name, &len) == -1)
        return -1;
    dgram->socket = s;

    return 0;
}
